#ifndef DPKGINTERFACE_H
#define DPKGINTERFACE_H

#include <QObject>

class DpkgInterface : public QObject
{
    Q_OBJECT
public:
    explicit DpkgInterface(QObject *parent = 0);
	virtual ~DpkgInterface();

	bool loadDebFiles(QStringList files_);


private:
	DpkgInterface(const DpkgInterface& old);
	DpkgInterface operator= (const DpkgInterface& old);

};

#endif // DPKGINTERFACE_H
